==> pyHarmonyTooling-0.1.1-py39-none-any.whl: test/1_objects_tests/test_guitar_tab.py <==
from unittest import TestCase

from pychord import Chord
from pyharmonytools.guitar_tab.guitar_tab import GuitarTab
from pyharmonytools.harmony.cof_chord import CofChord


class TestGuitarTab(TestCase):
    def test_digest_tab_dgbd(self):
        tab = """
        e|--11-----11-----10-----11----|
        B|--11-----12-----11-----11----|
        G|--11-----13-----10-----11----|
        D|-----------------------------|
        A|-----------------------------|
        E|-----------------------------|
        """
        expected = {"2": Chord("Gb6"), "9": Chord("B6"), "16": Chord("Bb"), "23": Chord("Gb6")}
        res = GuitarTab.digest_tab_simplest_chords_in_a_bar(tab)
        for (chord_res, chord_expected) in zip(res.keys(), expected.keys()):
            if CofChord.is_chord_included_from_components(expected[chord_expected], res[chord_res]):
                assert False
        assert True

    def test_digest_tab_d(self):
        tab = """
        e|--11---------------|
        B|------11-----------|
        G|-----------11------|
        D|-------------------|
        A|-------------------|
        E|-------------------|
        """
        expected = {"2": Chord("Gb6")}
        res = GuitarTab.digest_tab_simplest_chords_in_a_bar(tab)
        assert res == expected

    def test_digest_tab_eb(self):
        tab = """
        e|--11---|
        B|-------|
        G|-------|
        D|-------|
        A|-------|
        E|-------|
        """
        expected = {"2": Chord("Eb")}
        res = GuitarTab.digest_tab_simplest_chords_in_a_bar(tab)
        assert res == expected

    def test_digest_tab_bach(self):
        # see https://tabs.ultimate-guitar.com/tab/johann-sebastian-bach/cello-suite-no-1-prelude-tabs-799617
        tab = """
            Cello Suite No. 1 - Prelude
            Johann Sebastian Bach
            4/4
            Key: G Major
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----0---0---0-------0---0---0---|-----1-0-1---1-------1-0-1---1---|
            G|-------2---------------2---------|---------------------------------|
            D|---0-------0---0---0-------0---0-|---2-------2---2---2-------2---2-|
            A|---------------------------------|---------------------------------|
            E|-3---------------3---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-----0---0---0-------0---0---0---|
            G|-----5-4-5---5-------5-4-5---5---|---0---2---0---0---0---2---0-----|
            D|---4-------4---4---4-------4---4-|-------------------------------4-|
            A|---------------------------------|---------------------------------|
            E|-3---------------3---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----0---0-----------------------|---------------------------------|
            G|-------2---0---0---0---0---------|---0-2-0-2-0-2-0---0-2-0-2-0-2-0-|
            D|---2---------4---2---4-----0-----|---------------------------------|
            A|-------------------------2---4-2-|-4---------------4---------------|
            E|-3-------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----3-2-3-----------------------|---------------------------------|
            G|---2-------2-0-2---2-0-2---------|-----0---0---0-------0---0---0---|
            D|-4---------------4-------0-4-2-0-|-------4---------------4---------|
            A|---------------------------------|---2-------2---2---2-------2---2-|
            E|---------------------------------|-0---------------0---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----------------------3-2-0-----|-------3---3---------------------|
            G|-----------------0-----------2-0-|---------2-----2-------2-0-------|
            D|-----0-2-0---------4-2-----------|-4-2-0-------4---0-2-4-----4-2-0-|
            A|---4-------4-2-0-----------------|---------------------------------|
            E|-0-------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-------0-1-------------0-1-------|
            G|-1-----------1---4-----------1---|-----2-----2---------2-----2-----|
            D|---0-3-2-3-0---0---0-3-2-3-0---0-|---2---------2-0---2---------4-2-|
            A|---------------------------------|-3---------------3---------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|---------------------------------|
            G|---------------------------------|-0-----0---0-2---0---------------|
            D|---4---4-7-4-7-4---4---4-7-4-7-4-|---4-2---4-----4---4-2-0---------|
            A|-6---6-----------6---6-----------|-------------------------3-2-0---|
            E|---------------------------------|-------------------------------3-|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|---------------------------------|
            G|---------------------------------|---------------------------------|
            D|-----0---0---0-------0---0---0---|-----3-2-3---3-------3-2-3---3---|
            A|---3---3---3---3---3---3---3---3-|---2-------2---2---2-------2---2-|
            E|-2---------------2---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-------0---------------0---------|
            G|---------------------------------|-----5---5---5-------5---5---5---|
            D|-----2-0-2---2-------2-0-2---2---|---4-------4---4---4-------4---4-|
            A|---3-------3---3---3-------3---3-|---------------------------------|
            E|-3---------------3---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----0---0-----------------------|---------------------------------|
            G|-------2---0---------------------|---------0-----0---------0-----0-|
            D|---0---------4-2-0-------------0-|-----2-4---2-4-------2-4---2-4---|
            A|-------------------3-2-0---------|-4-0-------------3-0-------------|
            E|-3-----------------------3-2-0---|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-----------2-3~~~~---------------|
            G|---------------------------------|---------2---------------------0-|
            D|-----0-2-4-0-2-4-----0-2-4-0-2-4-|-----0-4-----------------0-2-4---|
            A|-3-0-------------3-0-------------|-3-0---------------0-2-3---------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------0-1---------0-1-3-|-4-3-2-3-3-1-0-1-1---------------|
            G|-2---------0-2-----2---0-2-------|-------------------2-------------|
            D|---4-0-2-4-----------4-----------|---------------------4-2-0-------|
            A|---------------------------------|---------------------------0-2-3-|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----------0-1---0---------------|-------------0---2---------------|
            G|---------2-----2---0-------------|---------0-2---0---3-2-3-3-2-1-2-|
            D|-0---0-4-------------0-----------|-0-----0-------------------------|
            A|---0-------------------3-2---0-2-|-----2---------------------------|
            E|---------------------------3-----|---3-----------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------2-3-2-|-3-------------------------------|
            G|-2-0---0-0-------------0-2-------|---2-------2---------------------|
            D|-----4-----2---------2-----------|-----4-2-4---0-4---0-------------|
            A|-------------4-2-0-4-------------|-----------------0---4-2-0-------|
            E|---------------------------------|---------------------------3-2-0-|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----1-0-----------1-0-----------|---0-----------------------------|
            G|---------2-0-----------2-0-------|-----2-0-----------2-0-----------|
            D|-0~~~--------4-2-0---------4-2-0-|---------4-2-0---------4-2-0-----|
            A|---------------------------------|-3-------------3-2-----------3-2-|
            E|---------------------------------|---------------------------------|
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|---------------------------------|
            G|---0-------2---2---2---2-0-2---2-|---2---2-0-2---2---2---2-0-2---2-|
            D|-----4-2-4---0---2---4-------2---|-4---0-------2---4---0-------2---|
            A|-0-------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-------------------------0-------|-----0---1-------0---1---3---0---|
            G|---2---2---2---2-0-2-2-2---2---2-|-2-2---2---2---2---2---2---2---2-|
            D|-4---0---2---4---------------0---|-------------0-------------------|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-1---0---1-------0-------0-------|---------------------------------|
            G|---2---2---2-2-2---2-2-2---2-0-2-|-2-2-0-2-2-2---2-0-2---2-0-2---2-|
            D|---------------------------------|-------------4-------4-------2---|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------0---1---2---|
            B|---------------------------------|-0---1---2---3---4---------------|
            G|---2-------------0---1---2---3---|---------------------------------|
            D|-4---0-2-3-0-4-0---0---0---0---0-|---0---0---0---0---0---0---0---0-|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|-3-------3---3---3-------3---3---|-3-------3---3---3-------3---3---|
            B|---0---0---0---0---0---0---0---0-|---------------------------------|
            G|---------------------------------|---2---2---2---2---2---2---2---2-|
            D|-----0---------------0-----------|-----0---------------0-----------|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|-2-------2---2---2-------2---2---|-3~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~-|
            B|---1---1---1---1---1---1---1---1-|-0~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~-|
            G|---------------------------------|---------------------------------|
            D|-----0---------------0-----------|---------------------------------|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|-3~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~-|        
        """
        assert False

==> pyHarmonyTooling-0.1.4-py39-none-any.whl: test/1_objects_tests/test_guitar_tab.py <==
from unittest import TestCase

from deepdiff import DeepDiff
from pychord import Chord

from pyharmonytools.displays.unit_test_report import UnitTestReport
from pyharmonytools.guitar_tab.guitar_tab import GuitarTab
from pyharmonytools.harmony.cof_chord import CofChord
from pyharmonytools.harmony.note import Note


class TestGuitarTab(TestCase):
    ut_report = UnitTestReport()

    def test_get_notes_from_chord_layout(self):
        chord_layout = [-1, -1, -1, 11, 11, 11]
        res = GuitarTab.get_notes_from_chord_layout(chord_layout)
        expected = [None, None, None, Note("Gb"), Note("Bb"), Note("Eb")]
        self.ut_report.assertTrue(res == expected)

    def test_digest_tab_readme(self):
        tab = """
              e|--11-----11-----10-----11---|
              B|--11-----12-----11-----11---|
              G|--11-----13-----10-----11---|
              D|----------------------------|
              A|----------------------------|
              E|----------------------------|
        """
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        expected = {"2": Chord("D#m"), "9": Chord("G#m"), "16": Chord("Bb"), "23": Chord("D#m")}
        diff = DeepDiff(res, expected, ignore_order=True)
        self.ut_report.assertTrue(diff == {})

    def test_digest_tab_dgbd(self):
        tab = """
        e|--11-----11-----10-----11----|
        B|--11-----12-----11-----11----|
        G|--11-----13-----10-----11----|
        D|-----------------------------|
        A|-----------------------------|
        E|-----------------------------|
        """
        expected = {"2": Chord("Gb6"), "9": Chord("B6"), "16": Chord("Bb"), "23": Chord("Gb6")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        found = False
        for (chord_res, chord_expected) in zip(res.keys(), expected.keys()):
            if CofChord.is_chord_included_from_components(expected[chord_expected], res[chord_res]):
                found = True
        self.ut_report.assertTrue(found)

    def test_digest_tab_gb6(self):
        tab = """
        e|--11---------------|
        B|------11-----------|
        G|-----------11------|
        D|-------------------|
        A|-------------------|
        E|-------------------|
        """
        expected = {"2": Chord("Gb6")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        self.ut_report.assertTrue(len(res.keys()) == len(expected.keys()))
        self.ut_report.assertTrue(CofChord.are_chord_equals(res["2"], expected["2"]))

    def test_digest_tab_gb6_d(self):
        tab = """
        e|--11------------2---|
        B|------11--------3---|
        G|-----------11---2---|
        D|--------------------|
        A|--------------------|
        E|--------------------|
        """
        expected = {"2": Chord("Gb6"), "16": Chord("D")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        self.ut_report.assertTrue(len(res.keys()) == len(expected.keys()))
        self.ut_report.assertTrue(CofChord.are_chord_equals(res["2"], expected["2"]))

    def test_digest_tab_eb(self):
        tab = """
        e|--11---|
        B|-------|
        G|-------|
        D|-------|
        A|-------|
        E|-------|
        """
        expected = {"2": Chord("Eb")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        self.ut_report.assertTrue(res == expected)

    def test_digest_tab_full_bach(self):
        # see https://tabs.ultimate-guitar.com/tab/johann-sebastian-bach/cello-suite-no-1-prelude-tabs-799617
        tab = """
            Cello Suite No. 1 - Prelude
            Johann Sebastian Bach
            4/4
            Key: G Major
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----0---0---0-------0---0---0---|-----1-0-1---1-------1-0-1---1---|
            G|-------2---------------2---------|---------------------------------|
            D|---0-------0---0---0-------0---0-|---2-------2---2---2-------2---2-|
            A|---------------------------------|---------------------------------|
            E|-3---------------3---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-----0---0---0-------0---0---0---|
            G|-----5-4-5---5-------5-4-5---5---|---0---2---0---0---0---2---0-----|
            D|---4-------4---4---4-------4---4-|-------------------------------4-|
            A|---------------------------------|---------------------------------|
            E|-3---------------3---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----0---0-----------------------|---------------------------------|
            G|-------2---0---0---0---0---------|---0-2-0-2-0-2-0---0-2-0-2-0-2-0-|
            D|---2---------4---2---4-----0-----|---------------------------------|
            A|-------------------------2---4-2-|-4---------------4---------------|
            E|-3-------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----3-2-3-----------------------|---------------------------------|
            G|---2-------2-0-2---2-0-2---------|-----0---0---0-------0---0---0---|
            D|-4---------------4-------0-4-2-0-|-------4---------------4---------|
            A|---------------------------------|---2-------2---2---2-------2---2-|
            E|---------------------------------|-0---------------0---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----------------------3-2-0-----|-------3---3---------------------|
            G|-----------------0-----------2-0-|---------2-----2-------2-0-------|
            D|-----0-2-0---------4-2-----------|-4-2-0-------4---0-2-4-----4-2-0-|
            A|---4-------4-2-0-----------------|---------------------------------|
            E|-0-------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-------0-1-------------0-1-------|
            G|-1-----------1---4-----------1---|-----2-----2---------2-----2-----|
            D|---0-3-2-3-0---0---0-3-2-3-0---0-|---2---------2-0---2---------4-2-|
            A|---------------------------------|-3---------------3---------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|---------------------------------|
            G|---------------------------------|-0-----0---0-2---0---------------|
            D|---4---4-7-4-7-4---4---4-7-4-7-4-|---4-2---4-----4---4-2-0---------|
            A|-6---6-----------6---6-----------|-------------------------3-2-0---|
            E|---------------------------------|-------------------------------3-|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|---------------------------------|
            G|---------------------------------|---------------------------------|
            D|-----0---0---0-------0---0---0---|-----3-2-3---3-------3-2-3---3---|
            A|---3---3---3---3---3---3---3---3-|---2-------2---2---2-------2---2-|
            E|-2---------------2---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-------0---------------0---------|
            G|---------------------------------|-----5---5---5-------5---5---5---|
            D|-----2-0-2---2-------2-0-2---2---|---4-------4---4---4-------4---4-|
            A|---3-------3---3---3-------3---3-|---------------------------------|
            E|-3---------------3---------------|-3---------------3---------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----0---0-----------------------|---------------------------------|
            G|-------2---0---------------------|---------0-----0---------0-----0-|
            D|---0---------4-2-0-------------0-|-----2-4---2-4-------2-4---2-4---|
            A|-------------------3-2-0---------|-4-0-------------3-0-------------|
            E|-3-----------------------3-2-0---|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|-----------2-3~~~~---------------|
            G|---------------------------------|---------2---------------------0-|
            D|-----0-2-4-0-2-4-----0-2-4-0-2-4-|-----0-4-----------------0-2-4---|
            A|-3-0-------------3-0-------------|-3-0---------------0-2-3---------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------0-1---------0-1-3-|-4-3-2-3-3-1-0-1-1---------------|
            G|-2---------0-2-----2---0-2-------|-------------------2-------------|
            D|---4-0-2-4-----------4-----------|---------------------4-2-0-------|
            A|---------------------------------|---------------------------0-2-3-|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----------0-1---0---------------|-------------0---2---------------|
            G|---------2-----2---0-------------|---------0-2---0---3-2-3-3-2-1-2-|
            D|-0---0-4-------------0-----------|-0-----0-------------------------|
            A|---0-------------------3-2---0-2-|-----2---------------------------|
            E|---------------------------3-----|---3-----------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------2-3-2-|-3-------------------------------|
            G|-2-0---0-0-------------0-2-------|---2-------2---------------------|
            D|-----4-----2---------2-----------|-----4-2-4---0-4---0-------------|
            A|-------------4-2-0-4-------------|-----------------0---4-2-0-------|
            E|---------------------------------|---------------------------3-2-0-|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-----1-0-----------1-0-----------|---0-----------------------------|
            G|---------2-0-----------2-0-------|-----2-0-----------2-0-----------|
            D|-0~~~--------4-2-0---------4-2-0-|---------4-2-0---------4-2-0-----|
            A|---------------------------------|-3-------------3-2-----------3-2-|
            E|---------------------------------|---------------------------------|
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|---------------------------------|---------------------------------|
            G|---0-------2---2---2---2-0-2---2-|---2---2-0-2---2---2---2-0-2---2-|
            D|-----4-2-4---0---2---4-------2---|-4---0-------2---4---0-------2---|
            A|-0-------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-------------------------0-------|-----0---1-------0---1---3---0---|
            G|---2---2---2---2-0-2-2-2---2---2-|-2-2---2---2---2---2---2---2---2-|
            D|-4---0---2---4---------------0---|-------------0-------------------|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------------------|
            B|-1---0---1-------0-------0-------|---------------------------------|
            G|---2---2---2-2-2---2-2-2---2-0-2-|-2-2-0-2-2-2---2-0-2---2-0-2---2-|
            D|---------------------------------|-------------4-------4-------2---|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|---------------------------------|---------------------0---1---2---|
            B|---------------------------------|-0---1---2---3---4---------------|
            G|---2-------------0---1---2---3---|---------------------------------|
            D|-4---0-2-3-0-4-0---0---0---0---0-|---0---0---0---0---0---0---0---0-|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|-3-------3---3---3-------3---3---|-3-------3---3---3-------3---3---|
            B|---0---0---0---0---0---0---0---0-|---------------------------------|
            G|---------------------------------|---2---2---2---2---2---2---2---2-|
            D|-----0---------------0-----------|-----0---------------0-----------|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|---------------------------------|
             
             
               |       |       |       |         |       |       |       |
            e|-2-------2---2---2-------2---2---|-3~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~-|
            B|---1---1---1---1---1---1---1---1-|-0~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~-|
            G|---------------------------------|---------------------------------|
            D|-----0---------------0-----------|---------------------------------|
            A|---------------------------------|---------------------------------|
            E|---------------------------------|-3~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~-|        
        """
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        # a lot of things are not yet implemented to make this run
        # we need first to split the bars
        self.ut_report.assertTrue(False)

    def test_digest_bach_bar_1(self):
        tab = """
  e|---------------------------------|
  B|-----0---0---0-------0---0---0---|
  G|-------2---------------2---------|
  D|---0-------0---0---0-------0---0-|
  A|---------------------------------|
  E|-3---------------3---------------|
  """
        expected = {'1': Chord("G"), '7': Chord("D5/B"), '13': Chord("G"), '17': Chord("G5"),
                    '21': Chord("G"), '29': Chord("G")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        diff = DeepDiff(res, expected, ignore_order=True)
        self.ut_report.assertTrue(diff == {})

    def test_digest_tab_simplest_progressive_chords_in_a_bar_gb6(self):
        tab = """
        e|--11---------------|
        B|------11-----------|
        G|-----------11------|
        D|-------------------|
        A|-------------------|
        E|-------------------|
        """
        expected = {"2": Chord("Gb6")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        self.ut_report.assertTrue(len(res.keys()) == len(expected.keys()))
        self.ut_report.assertTrue(CofChord.are_chord_equals(res["2"], expected["2"]))

    def test_digest_tab_simplest_progressive_chords_in_a_bar_gb6_d(self):
        tab = """
        e|--11------------2---|
        B|------11--------3---|
        G|-----------11---2---|
        D|--------------------|
        A|--------------------|
        E|--------------------|
        """
        expected = {"2": Chord("Gb6"), "16": Chord("D")}
        res = GuitarTab.digest_tab_simplest_progressive_chords_in_a_bar(tab)
        self.ut_report.assertTrue(len(res.keys()) == len(expected.keys()))
        self.ut_report.assertTrue(CofChord.are_chord_equals(res["2"], expected["2"]))
        self.ut_report.assertTrue(CofChord.are_chord_equals(res["16"], expected["16"]))
